@@ -20,5 +20,5 @@ class QLearning(TD):
 
         q_next = np.max(self.Q[next_state, :]) if not absorbing else 0.
 
-        self.Q[state, action] = q_current + self.alpha(state, action) * (
+        self.Q[state, action] = q_current + self._alpha(state, action) * (
             reward + self.mdp_info.gamma * q_next - q_current)
