@@ -1,6 +1,6 @@
 import numpy as np
 
-from mushroom_rl.environments import Environment, MDPInfo
+from mushroom_rl.core import Environment, MDPInfo
 from mushroom_rl.utils import spaces
 
 
