@@ -1,4 +1,5 @@
 from .ball_in_a_cup import BallInACup
 from .humanoid_gait import HumanoidGait
 
-__all__ = ['BallInACup', "HumanoidGait"]
\ No newline at end of file
+BallInACup.register()
+HumanoidGait.register()
